# CNCPy
Python cursor for writing large amounts of CNC GCODE.
Correctly used, it can write thousands of lines in small scripts.

## Usage
---

### Installation
Simple run in your terminal:
```
python3 -m pip install CNCPy
```

### Setup
Run the following code to initialize the cursor.
```python
import CNCPy
c = CNCPy.GcodeCursor("outputfile.gcode")
```
Refer to the documentation for additional help.

NOTES
-----
Author: Roan Rothrock
 - @R-Rothrock: Github
 - roan.rothrock@bugcrowdninja.com: Bugcrowd
 - roan.rothrock@hotmail.com: Email
 
License: GNU General Public License
